@@ -343,6 +343,13 @@ class bigjob(api.base.bigjob):
         # (Python app cannot be passed inline in Condor job description)
         if lrms_saga_url.scheme.startswith("condor")==True:
 
+            bootstrap_script = self.__generate_bootstrap_script_from_binary(
+                                                          self.coordination.get_address(), 
+                                                          self.pilot_url, # Queue 1 used by this BJ object 
+                                                          external_queue  # Queue 2 used by Pilot Compute Service 
+                                                                          # or another external scheduler
+                                                          )
+     
             condor_bootstrap_filename = os.path.join("/tmp", "bootstrap-"+str(self.uuid))
             condor_bootstrap_file = open(condor_bootstrap_filename, "w")
             condor_bootstrap_file.write(bootstrap_script)
@@ -627,6 +634,57 @@ print "Starting BigJob Agents with following args: " + str(args)
 bigjob_agent = bigjob.bigjob_agent.bigjob_agent(args)
 """ % (coordination_host, coordination_namespace, external_coordination_namespace))
         return script
+    
+    def __generate_bootstrap_script_from_binary(self, coordination_host, coordination_namespace, 
+                                                external_coordination_namespace="", 
+                                                bigjob_home=None):
+        script = textwrap.dedent("""import sys
+import os
+import urllib
+import sys
+import time
+start_time = time.time()
+home = os.environ.get("HOME")
+#print "Home: " + home
+if home==None: home = os.getcwd()
+BIGJOB_AGENT_DIR= os.path.join(home, ".bigjob")
+if not os.path.exists(BIGJOB_AGENT_DIR): os.mkdir (BIGJOB_AGENT_DIR)
+BIGJOB_PYTHON_DIR=BIGJOB_AGENT_DIR+"/python/"
+if not os.path.exists(BIGJOB_PYTHON_DIR): os.mkdir(BIGJOB_PYTHON_DIR)
+BOOTSTRAP_URL="http://s3.amazonaws.com/bigjob/bigjob-Linux-x86_64.tar.gz"
+BOOTSTRAP_FILE="bigjob-Linux-x86_64.tar.gz"
+#ensure that BJ in .bigjob is upfront in sys.path
+sys.path.insert(0, os.getcwd() + "/../")
+#sys.path.insert(0, /User/luckow/.bigjob/python/lib")
+#sys.path.insert(0, os.getcwd() + "/../../")
+p = list()
+for i in sys.path:
+    if i.find(\".bigjob/python\")>1:
+          p.insert(0, i)
+for i in p: sys.path.insert(0, i)
+print "Python path: " + str(sys.path)
+print "Python version: " + str(sys.version_info)
+try: import saga
+except: print "SAGA and SAGA Python Bindings not found.";
+try: import bigjob.bigjob_agent
+except: 
+    print "BigJob not installed. Attempt to install it."; 
+    #opener = urllib.FancyURLopener({}); 
+    #ret = opener.retrieve(BOOTSTRAP_URL, BOOTSTRAP_FILE); 
+    print "Download via wget"
+    os.system("wget " + BOOTSTRAP_URL)
+    os.system("rm -rf .bigjob")
+    print "Execute: " + "tar -xzf " + BOOTSTRAP_FILE
+    os.system("ls -lta")
+    try:
+        os.system("tar -xzf " + BOOTSTRAP_FILE); 
+        os.system("ls -lta")
+        os.system(".bigjob/python/bin/python -c 'import bigjob; import bigjob.bigjob_agent; print bigjob.version; bigjob.bigjob_agent.bigjob_agent([\\"bigjob_agent.py\\", \\"%s\\", \\"%s\\", \\"%s\\"])'")
+    except:
+        print "BJ installation failed!";
+""" % (coordination_host, coordination_namespace, external_coordination_namespace))
+        return script
+
 
     def __escape_rsl(self, bootstrap_script):
         logger.debug("Escape RSL")
